@@ -48,6 +48,8 @@ public:
 
 private slots:
     void addFiles();
+    void revertFiles();
+    void showLocalChanges();
     void removeFiles();
     void checkout();
     void commit();
@@ -102,6 +104,8 @@ private:
      */
     QHash<QString, ItemVersion> m_versionInfoHash;
     QAction* m_addAction;
+    QAction* m_revertAction;
+    QAction* m_showLocalChangesAction;
     QAction* m_removeAction;
     QAction* m_checkoutAction;
     QAction* m_commitAction;
