@@ -22,6 +22,8 @@
 
 #include <Dolphin/KVersionControlPlugin>
 
+#include <KFileItemList>
+
 #include <QHash>
 #include <QProcess>
 #include <QTemporaryFile>
@@ -51,6 +53,7 @@ private slots:
     void commitFiles();
     void addFiles();
     void removeFiles();
+    void revertFiles();
 
     void slotOperationCompleted(int exitCode, QProcess::ExitStatus exitStatus);
     void slotOperationError();
@@ -76,7 +79,7 @@ private:
 
     void startSvnCommandProcess();
 
-    QList<QAction*> directoryActions(const QString& directory) const;
+    QList<QAction*> directoryActions(const KFileItem &directory) const;
 
 private:
     bool m_pendingOperation;
@@ -87,6 +90,7 @@ private:
     QAction* m_commitAction;
     QAction* m_addAction;
     QAction* m_removeAction;
+    QAction* m_revertAction;
     QAction* m_showUpdatesAction;
 
     QString m_command;
